==> open-xchange-publish_7.0.0.orig.tar.bz2: open-xchange-publish-7.0.0/com.openexchange.publish.json/src/com/openexchange/publish/json/Hostname.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the Open-Xchange, Inc. group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2004-2012 Open-Xchange, Inc.
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.publish.json;

import com.openexchange.groupware.notify.hostname.HostnameService;
import com.openexchange.publish.Publication;


/**
 * {@link Hostname}
 *
 * @author <a href="mailto:francisco.laguna@open-xchange.com">Francisco Laguna</a>
 */
public class Hostname {
    private static final Hostname INSTANCE = new Hostname();

    private HostnameService hostnameService;

    public String getHostname(Publication pub) {
        if(hostnameService == null) {
            return null;
        }
        return hostnameService.getHostname(pub.getUserId(), pub.getContext().getContextId());
    }


    public void setHostnameService(HostnameService hostnameService) {
        this.hostnameService = hostnameService;
    }

    private Hostname() {

    }

    public static Hostname getInstance() {
        return INSTANCE;
    }
}

==> open-xchange-publish_7.4.0.orig.tar.bz2: open-xchange-publish-7.4.0/com.openexchange.publish.json/src/com/openexchange/publish/json/Hostname.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the Open-Xchange, Inc. group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2004-2012 Open-Xchange, Inc.
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.publish.json;

import java.util.concurrent.atomic.AtomicReference;
import com.openexchange.groupware.notify.hostname.HostnameService;
import com.openexchange.publish.Publication;

/**
 * {@link Hostname} - Provides the host name for a given publication.
 *
 * @author <a href="mailto:francisco.laguna@open-xchange.com">Francisco Laguna</a>
 */
public class Hostname {

    private static final Hostname INSTANCE = new Hostname();

    /**
     * Gets the instance.
     *
     * @return The instance
     */
    public static Hostname getInstance() {
        return INSTANCE;
    }

    // ------------------------------------------------------------------------- //

    private final AtomicReference<HostnameService> hostnameService;

    /**
     * Prevent initialization.
     */
    private Hostname() {
        super();
        hostnameService = new AtomicReference<HostnameService>();
    }

    /**
     * Gets the host name for given publication.
     *
     * @param pub The publication
     * @return The associated host name
     */
    public String getHostname(final Publication pub) {
        if (null == pub) {
            return null;
        }
        final HostnameService hostnameService = this.hostnameService.get();
        if (hostnameService == null) {
            return null;
        }
        return hostnameService.getHostname(pub.getUserId(), pub.getContext().getContextId());
    }

    /**
     * Sets the host name service.
     *
     * @param hostnameService The service
     */
    public void setHostnameService(final HostnameService hostnameService) {
        this.hostnameService.set(hostnameService);
    }

}
